<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Irish_Thunderbird
</name>

<description>
   <am>Irish localisation of Thunderbird</am>
   <ar>Irish localisation of Thunderbird</ar>
   <be>Irish localisation of Thunderbird</be>
   <bg>Irish localisation of Thunderbird</bg>
   <bn>Irish localisation of Thunderbird</bn>
   <ca>Irish localisation of Thunderbird</ca>
   <cs>Irish localisation of Thunderbird</cs>
   <da>Irish localisation of Thunderbird</da>
   <de>Irische Lokalisation von Thunderbird</de>
   <el>Ιρλανδικά για Firefox ESR</el>
   <en>Irish localisation of Thunderbird</en>
   <es_ES>Localización Irlandés de Thunderbird</es_ES>
   <es>Localización Irlandés de Thunderbird</es>
   <et>Irish localisation of Thunderbird</et>
   <eu>Irish localisation of Thunderbird</eu>
   <fa>Irish localisation of Thunderbird</fa>
   <fil_PH>Irish localisation of Thunderbird</fil_PH>
   <fi>Irish localisation of Thunderbird</fi>
   <fr_BE>Irish localisation of Thunderbird</fr_BE>
   <fr>Localisation en irlandais de Thunderbird</fr>
   <gl_ES>Irish localisation of Thunderbird</gl_ES>
   <gu>Irish localisation of Thunderbird</gu>
   <he_IL>Irish localisation of Thunderbird</he_IL>
   <hi>Irish localisation of Thunderbird</hi>
   <hr>Irish localisation of Thunderbird</hr>
   <hu>Irish localisation of Thunderbird</hu>
   <id>Irish localisation of Thunderbird</id>
   <is>Irish localisation of Thunderbird</is>
   <it>Localizzazione irlandese di Thunderbird</it>
   <ja>アイルランド語版 Thunderbird</ja>
   <kk>Irish localisation of Thunderbird</kk>
   <ko>Irish localisation of Thunderbird</ko>
   <lt>Irish localisation of Thunderbird</lt>
   <mk>Irish localisation of Thunderbird</mk>
   <mr>Irish localisation of Thunderbird</mr>
   <nb_NO>Irish localisation of Thunderbird</nb_NO>
   <nb>Irsk lokaltilpassing av Thunderbird</nb>
   <nl_BE>Irish localisation of Thunderbird</nl_BE>
   <nl>Irish localisation of Thunderbird</nl>
   <pl>Irish localisation of Thunderbird</pl>
   <pt_BR>Irlandês Localização para o Thunderbird</pt_BR>
   <pt>Irish localisation of Thunderbird</pt>
   <ro>Irish localisation of Thunderbird</ro>
   <ru>Irish localisation of Thunderbird</ru>
   <sk>Irish localisation of Thunderbird</sk>
   <sl>Irish localisation of Thunderbird</sl>
   <sq>Irish localisation of Thunderbird</sq>
   <sr>Irish localisation of Thunderbird</sr>
   <sv>Irländsk lokalisering av Thunderbird</sv>
   <th>Irish localisation of Thunderbird</th>
   <tr>Thunderbird'ün İrlandaca yerelleştirmesi</tr>
   <uk>Irish localisation of Thunderbird</uk>
   <vi>Irish localisation of Thunderbird</vi>
   <zh_CN>Irish localisation of Thunderbird</zh_CN>
   <zh_HK>Irish localisation of Thunderbird</zh_HK>
   <zh_TW>Irish localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
thunderbird-l10n-ga-ie
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
thunderbird-l10n-ga-ie
</uninstall_package_names>

</app>
